[![Build Status](https://api.travis-ci.org/uw-it-aca/uw-restclients-grad.svg?branch=master)](https://travis-ci.org/uw-it-aca/uw-restclients-grad)
[![Coverage Status](https://coveralls.io/repos/uw-it-aca/uw-restclients-grad/badge.png?branch=master)](https://coveralls.io/r/uw-it-aca/uw-restclients-grad?branch=master)

# uw-restclients-grad
The restclient interacting with the Grad WS API.
